Post Survey
-----------------------------------------------------

Please answer the following questions.

==============

.. shortanswer:: class-exp-post-1-age

    What is your age in years?

.. shortanswer:: class-exp-post-2-major

    What is your major or intended major, or program of study?

.. shortanswer:: class-exp-post-3-gender

    What is your gender identity (woman, man, non-binary,  etc, prefer not to say)?

.. shortanswer:: class-exp-post-4-year

   What year are you in of your undergraduate education (1st, 2nd, 3rd, etc)?

.. shortanswer:: class-exp-post-5-dis

   Please list any learning issues we should be aware of like Dyslexia, Autism, ADHD, etc or enter none.

.. shortanswer:: class-exp-post-6-hours

   About how many hours have you been programming in Python?

.. shortanswer:: class-exp-post-7-langs

   What language(s) do you speak at home?

.. poll:: class-exp-post-8-read
    :option_1: Poor
    :option_2: Below Average
    :option_3: Average
    :option_4: Above Average
    :option_5: Excellent
    :results: instructor

    Rate your ability to read English

.. poll:: class-exp-post-9-understand-spoken
    :option_1: Poor
    :option_2: Below Average
    :option_3: Average
    :option_4: Above Average
    :option_5: Excellent
    :results: instructor

    Rate your ability to understand spoken English

.. poll:: class-exp-post-10-parsons
   :option_1: No
   :option_2: Yes

   Had you solved any mixed-up code (Parsons) problems like the one below before you took part in this study?

A mixed-up code (Parsons) problem.

.. image:: https://i.postimg.cc/wBFZ98zz/parsons.png
